package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.ElasticScalingServices;

/**
 * 弹性伸缩服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IElasticScalingServicesService 
{
    /**
     * 查询弹性伸缩服务
     * 
     * @param id 弹性伸缩服务主键
     * @return 弹性伸缩服务
     */
    public ElasticScalingServices selectElasticScalingServicesById(Integer id);

    /**
     * 查询弹性伸缩服务列表
     * 
     * @param elasticScalingServices 弹性伸缩服务
     * @return 弹性伸缩服务集合
     */
    public List<ElasticScalingServices> selectElasticScalingServicesList(ElasticScalingServices elasticScalingServices);

    /**
     * 新增弹性伸缩服务
     * 
     * @param elasticScalingServices 弹性伸缩服务
     * @return 结果
     */
    public int insertElasticScalingServices(ElasticScalingServices elasticScalingServices);

    /**
     * 修改弹性伸缩服务
     * 
     * @param elasticScalingServices 弹性伸缩服务
     * @return 结果
     */
    public int updateElasticScalingServices(ElasticScalingServices elasticScalingServices);

    /**
     * 批量删除弹性伸缩服务
     * 
     * @param ids 需要删除的弹性伸缩服务主键集合
     * @return 结果
     */
    public int deleteElasticScalingServicesByIds(Integer[] ids);

    /**
     * 删除弹性伸缩服务信息
     * 
     * @param id 弹性伸缩服务主键
     * @return 结果
     */
    public int deleteElasticScalingServicesById(Integer id);
}
